@@ -15,6 +15,7 @@ def test_topics():
     5. Correct metric nature for energy/power types
     6. Valid topic structure patterns
     7. Valid short_id format (lowercase letters, numbers, hyphens, underscores, and placeholders; cannot start/end with underscore)
+    8. No Duplicate DeviceTypes + Names (except for attributes)
     """
     from victron_mqtt._victron_topics import topics
     from victron_mqtt.constants import MetricKind, ValueType, MetricType, MetricNature
@@ -30,7 +31,17 @@ def test_topics():
                 errors.append(f"Duplicate short_id '{short_id}' found in topics: '{descriptor.topic}' and '{short_ids[short_id]}'")
             else:
                 short_ids[short_id] = descriptor.topic
-    
+
+    # Check for duplicate devices+names
+    names = {}
+    for descriptor in topics:
+        if descriptor.message_type != MetricKind.ATTRIBUTE:
+            name = f"devicetype '{descriptor.device_type}' name '{descriptor.name}'"
+            if name in names:
+                errors.append(f"Duplicate {name} found in topics: '{descriptor.topic}' and '{names[name]}'")
+            else:
+                names[name] = descriptor.topic
+
     # Check for inconsistent naming patterns
     for descriptor in topics:        
         # Check for inconsistent name vs unit_of_measurement mismatch
@@ -161,6 +172,28 @@ def test_topics():
         if '//' in descriptor.topic:
             errors.append(f"Topic '{descriptor.topic}' contains invalid '//' sequence")
     
+    # Check for valid device_type in topics
+    from victron_mqtt._victron_enums import DeviceType
+    # Collect all valid device type codes from DeviceType
+    valid_device_types = {member.code for member in DeviceType}
+
+    # Validate device_type in topics, skipping ATTRIBUTE topics
+    for descriptor in topics:
+        if descriptor.message_type == MetricKind.ATTRIBUTE:
+            continue
+
+        topic_parts = descriptor.topic.split('/')
+        if len(topic_parts) > 2:
+            device_type = topic_parts[2]
+            if device_type != "settings" and device_type not in valid_device_types:
+                errors.append(f"Topic '{descriptor.topic}' has invalid device_type '{device_type}' not defined in DeviceType")
+
+            # If the topic is related to settings, validate part[5] as the actual device type
+            if len(topic_parts) > 5 and topic_parts[2] == 'settings':
+                actual_device_type = topic_parts[5]
+                if actual_device_type not in valid_device_types:
+                    errors.append(f"Settings topic '{descriptor.topic}' has invalid actual device_type '{actual_device_type}' not defined in DeviceType")
+    
     # Report all errors
     if errors:
         error_message = "\n".join([f"  - {error}" for error in errors])
